/*--------------------------------------------------------------------------------------------------
  Copyright (c) Microsoft Corporation. All rights reserved.
  --------------------------------------------------------------------------------------------------*/

  var nav;
  var currentScale = 1;
  var navHeight = 48;
  var timeoutObj;
  var scrollTimeoutObj;
  var lastViewportPosition = {};
  var lastScrollPosition = {};

  $(document).ready(function() {
      configureInput();

      window.addEventListener('touchmove', function(e) {
          setScale();
      }, { passive: true, capture: true });

      document.getElementsByClassName('fr-layout-pagesection')[0].addEventListener('scroll', function(e) {
          setPos();
      }, { passive: true, capture: true });

      window.addEventListener('touchend', function(e) {
          listenToScrollEnd();
      }, { passive: true, capture: true });

      window.addEventListener('orientationchange', function() {
          clearTimeoutObj();
          var afterOrientationChange = function() {
              setScale();
              window.removeEventListener('resize', afterOrientationChange);
          };
          window.addEventListener('resize', afterOrientationChange);
      });

      window.addEventListener('resize', function() {
        setPos();
        window.addEventListener("scroll", setPosAfterScroll);
      });

      $(document).on("reportviewersetpagedone", ".fr-layout-mainviewport", function() {
        setPos();
      });
  });

  function clearTimeoutObj() {
      if (timeoutObj) {
        clearTimeout(timeoutObj);
      }
  }

  function configureInput() {
    $(".fr-toolbar-reportpage-textbox.fr-core-input").attr("type", "number");
  }

  function setScale() {
    if (window.visualViewport.scale !== currentScale && nav) {
        currentScale = window.visualViewport.scale;
        nav.style["transform"] = "scale(" + (1 / currentScale) + ")";
    }
    setPos();
  }

  function setPos() {
      if (!nav) {
          nav = document.getElementsByClassName('fr-toolbar')[0];
      }

      if (nav) {
          nav.style.top = (window.visualViewport.height + window.visualViewport.offsetTop - navHeight) + "px";
          nav.style.left = window.visualViewport.offsetLeft + "px";
      }
  }

  function setPosAfterScroll() {
    listenToScrollEnd(function() {
        window.removeEventListener("scroll", setPosAfterScroll);
    });
  }

  function listenToScrollEnd(callback) {
    clearTimeoutObj();

    timeoutObj = setTimeout(function() {
        if (window.visualViewport.offsetTop !== lastViewportPosition.offsetTop ||
            window.visualViewport.offsetLeft !== lastViewportPosition.offsetLeft) {
                // still scrolling
                listenToScrollEnd(callback);
        }
        else {
            if (callback) { callback(); }
            // no scrolling
            setScale();
        }
    }, 50);

    lastViewportPosition.offsetTop = window.visualViewport.offsetTop;
    lastViewportPosition.offsetLeft = window.visualViewport.offsetLeft;
  }